@@ -28,6 +28,8 @@ from .swagger.api.ap_is import (
     get_pipeline_api_client,
     get_pipeline_api_clients,
     get_pipeline_apis,
+    replace_model_api,
+    replace_pipeline_api,
 )
 from .swagger.api.data import (
     apply_data_prep_steps,
@@ -946,6 +948,20 @@ class AnalyzeSwaggerClientWrapper:
             get_model_api.sync(client=self._client, model_api_id=api_id)
         )
 
+    def replace_model_api_model(
+        self, api_id: int, new_model_id: int, notes: str
+    ) -> int:
+        response = replace_model_api.sync_detailed(
+            client=self._client,
+            model_api_id=api_id,
+            json_body=dto.UpdateDeployedModelApiRequest(
+                new_model_id=new_model_id, notes=notes
+            ),
+        )
+        return wait_for_future_to_succeed(self._client, response).additional_properties[
+            "id"
+        ]
+
     def list_model_api_clients(
         self, api_id: int
     ) -> List[dto.DeployedApiClientResponse]:
@@ -1022,6 +1038,20 @@ class AnalyzeSwaggerClientWrapper:
             get_pipeline_api.sync(client=self._client, pipeline_api_id=api_id)
         )
 
+    def replace_pipeline_api_pipeline(
+        self, api_id: int, new_pipeline_id: int, notes: str
+    ) -> int:
+        response = replace_pipeline_api.sync_detailed(
+            client=self._client,
+            pipeline_api_id=api_id,
+            json_body=dto.UpdateDeployedPipelineApiRequest(
+                new_pipeline_id=new_pipeline_id, notes=notes
+            ),
+        )
+        return wait_for_future_to_succeed(self._client, response).additional_properties[
+            "id"
+        ]
+
     def list_pipeline_api_clients(
         self, api_id: int
     ) -> List[dto.DeployedApiClientResponse]:
