@@ -1,5 +1,6 @@
 """ Contains all the data models used in inputs/outputs """
 
+from .api_history_response import ApiHistoryResponse
 from .apply_data_prep_steps_request import ApplyDataPrepStepsRequest
 from .apply_formula_step import ApplyFormulaStep
 from .apply_formula_step_step_type import ApplyFormulaStepStepType
@@ -135,3 +136,5 @@ from .transform_text_step_replace_existing_column import (
     TransformTextStepReplaceExistingColumn,
 )
 from .transform_text_step_step_type import TransformTextStepStepType
+from .update_deployed_model_api_request import UpdateDeployedModelApiRequest
+from .update_deployed_pipeline_api_request import UpdateDeployedPipelineApiRequest
